aboutsummaryrefslogtreecommitdiffstats
path: root/src/dumm/guest.h
diff options
context:
space:
mode:
authorMartin Willi <martin@strongswan.org>2007-08-08 12:35:24 +0000
committerMartin Willi <martin@strongswan.org>2007-08-08 12:35:24 +0000
commit7b7201bee6c771ddef5eb47216e860cf740e68a5 (patch)
treee19d2d08a8318d412b8ecf59bbe05b3f34baf597 /src/dumm/guest.h
parent3dcf9dbd70dbee8b9914eef98d3f7cc00203919b (diff)
downloadstrongswan-7b7201bee6c771ddef5eb47216e860cf740e68a5.tar.bz2
strongswan-7b7201bee6c771ddef5eb47216e860cf740e68a5.tar.xz
usable without scenarios
Diffstat (limited to 'src/dumm/guest.h')
-rw-r--r--src/dumm/guest.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/dumm/guest.h b/src/dumm/guest.h
index d9845e8a8..eb85ccb3c 100644
--- a/src/dumm/guest.h
+++ b/src/dumm/guest.h
@@ -21,14 +21,6 @@
#include "iface.h"
-#define MASTER_DIR "master"
-#define DIFF_DIR "diff"
-#define UNION_DIR "union"
-#define MEMORY_FILE "mem"
-#define KERNEL_FILE "linux"
-#define LOG_FILE "boot.log"
-#define NOTIFY_FILE "notify"
-
typedef enum guest_state_t guest_state_t;
/**
@@ -72,6 +64,7 @@ struct guest_t {
* @return name of the guest
*/
pid_t (*get_pid) (guest_t *this);
+
/**
* @brief Get the state of the guest (stopped, started, etc.).
*
@@ -82,10 +75,9 @@ struct guest_t {
/**
* @brief Start the guest.
*
- * @param kernel kernel to boot for this guest
* @return TRUE if guest successfully started
*/
- bool (*start) (guest_t *this, char *kernel);
+ bool (*start) (guest_t *this);
/**
* @brief Kill the guest.
@@ -95,7 +87,7 @@ struct guest_t {
bool (*stop) (guest_t *this);
/**
* @brief Create a new interface for that host.
*
* @param name name of the interface in the guest
* @return created interface, or NULL if failed
@@ -110,7 +102,15 @@ struct guest_t {
iterator_t* (*create_iface_iterator)(guest_t *this);
/**
- * @brief Called whenever a SIGCHILD is received.
+ * @brief Set the scenario COWFS overlay to use.
+ *
+ * @param parent parent directory where scenario diff should point to
+ * @return FALSE if failed
+ */
+ bool (*set_scenario)(guest_t *this, char *parent);
+
+ /**
+ * @brief Called whenever a SIGCHILD for the guests PID is received.
*/
void (*sigchild)(guest_t *this);
@@ -95,7 +87,7 @@ struct guest_t {
bool (*stop) (guest_t *this);
/**
- * @brief Create a new interface for that host.
+ * @brief Create a new interface in the current scenario.
*
* @param name name of the interface in the guest